pub fn validate_commit_msg(config: &ReleaseConfig) -> Result<(), ReleaseError>Expand description
Validate a commit message file against the configured conventional commit pattern and types. Reads hook JSON from stdin to get the message_file path.
pub fn validate_commit_msg(config: &ReleaseConfig) -> Result<(), ReleaseError>Validate a commit message file against the configured conventional commit pattern and types. Reads hook JSON from stdin to get the message_file path.