Enums
- Bump
Level - The kind of version bump to apply.
Functions
- apply_
bump - Apply a bump level to a version, returning the new version.
- apply_
prerelease_ bump - Apply a bump and produce a pre-release version.
- determine_
bump - Determine the highest bump level from a set of conventional commits.