Structs
- Commit
- A raw commit as read from git history.
- Commit
Type - Internal commit type representation — name + bump level.
- Conventional
Commit - A commit parsed according to the Conventional Commits specification.
- Default
Commit Classifier - Typed
Commit Parser - Parser that builds its pattern from configured type names.
Traits
- Commit
Classifier - Single source of truth for commit type classification.
- Commit
Parser - Parses raw commits into conventional commits.
Functions
- build_
commit_ pattern - Build the conventional commit regex from configured type names.
- default_
commit_ types