pub struct ReleaseConfig {Show 16 fields
pub branches: Vec<String>,
pub tag_prefix: String,
pub commit_pattern: String,
pub breaking_section: String,
pub misc_section: String,
pub types: Vec<CommitType>,
pub changelog: ChangelogConfig,
pub version_files: Vec<String>,
pub version_files_strict: bool,
pub artifacts: Vec<String>,
pub floating_tags: bool,
pub build_command: Option<String>,
pub stage_files: Vec<String>,
pub prerelease: Option<String>,
pub pre_release_command: Option<String>,
pub post_release_command: Option<String>,
}Fields
branches: Vec<String>tag_prefix: Stringcommit_pattern: Stringbreaking_section: Stringmisc_section: Stringtypes: Vec<CommitType>changelog: ChangelogConfigversion_files: Vec<String>version_files_strict: boolartifacts: Vec<String>build_command: Option<String>stage_files: Vec<String>Additional files/globs to stage after build_command runs (e.g. Cargo.lock).
prerelease: Option<String>Pre-release identifier (e.g. “alpha”, “beta”, “rc”). When set, versions are
formatted as X.Y.Z-
pre_release_command: Option<String>Shell command to run before the release starts (validation, checks).
post_release_command: Option<String>Shell command to run after the release completes (notifications, deployments).
Implementations
Sourceimpl ReleaseConfig
impl ReleaseConfig
Sourcepub fn load(path: &Path) -> Result<Self, ReleaseError>
pub fn load(path: &Path) -> Result<Self, ReleaseError>
Load config from a YAML file, falling back to defaults if the file doesn’t exist.