Hook execution for sr lifecycle events.
Runs configured shell commands at sr lifecycle boundaries. Hook context is passed as JSON via stdin so commands can act on structured data.
Structs
- Hook
Context - Context passed to hook commands as JSON on stdin.
Functions
- run_
commands - Run a list of shell commands with environment variables.
- run_
post_ release - Run post_release hooks from a HooksConfig.
- run_
pre_ release - Run pre_release hooks from a HooksConfig.
- run_
shell - Run a shell command (
sh -c), optionally piping data to stdin and/or injecting environment variables.