Module version_files

Module version_files 

Functions

bump_version_file
Bump the version field in the given manifest file.
discover_lock_files
Given a list of bumped manifest paths, discover associated lock files that exist on disk. Searches the manifest’s directory and ancestors (for monorepo roots). Returns deduplicated paths.